@@ -75,6 +75,9 @@ void Expression::makeSymbol(std::string const &symName) {
 	if (Symbol *sym = sym_FindScopedSymbol(symName); sym_IsPC(sym) && !sect_GetSymbolSection()) {
 		error("PC has no value outside of a section\n");
 		data = 0;
+	} else if (sym && !sym->isNumeric() && !sym->isLabel()) {
+		error("'%s' is not a numeric symbol\n", symName.c_str());
+		data = 0;
 	} else if (!sym || !sym->isConstant()) {
 		isSymbol = true;
 
@@ -91,7 +94,7 @@ void Expression::makeSymbol(std::string const &symName) {
 		*ptr++ = RPN_SYM;
 		memcpy(ptr, sym->name.c_str(), nameLen);
 	} else {
-		data = static_cast<int32_t>(sym_GetConstantValue(symName));
+		data = static_cast<int32_t>(sym->getConstantValue());
 	}
 }
 
@@ -322,40 +325,12 @@ void Expression::makeUnaryOp(RPNCommand op, Expression &&src) {
 		case RPN_TZCOUNT:
 			data = val != 0 ? ctz(uval) : 32;
 			break;
-
-		case RPN_LOGOR:
-		case RPN_LOGAND:
-		case RPN_LOGEQ:
-		case RPN_LOGGT:
-		case RPN_LOGLT:
-		case RPN_LOGGE:
-		case RPN_LOGLE:
-		case RPN_LOGNE:
-		case RPN_ADD:
-		case RPN_SUB:
-		case RPN_XOR:
-		case RPN_OR:
-		case RPN_AND:
-		case RPN_SHL:
-		case RPN_SHR:
-		case RPN_USHR:
-		case RPN_MUL:
-		case RPN_DIV:
-		case RPN_MOD:
-		case RPN_EXP:
-		case RPN_BANK_SYM:
-		case RPN_BANK_SECT:
-		case RPN_BANK_SELF:
-		case RPN_SIZEOF_SECT:
-		case RPN_STARTOF_SECT:
-		case RPN_SIZEOF_SECTTYPE:
-		case RPN_STARTOF_SECTTYPE:
-		case RPN_HRAM:
-		case RPN_RST:
-		case RPN_CONST:
-		case RPN_SYM:
-			fatalerror("%d is not an unary operator\n", op);
+		default:
+			// `makeUnaryOp` should never be called with a non-unary operator!
+			// LCOV_EXCL_START
+			unreachable_();
 		}
+		// LCOV_EXCL_STOP
 	} else if (op == RPN_LOGNOT && tryConstLogNot(src)) {
 		data = 0;
 	} else if (int32_t constVal; op == RPN_LOW && (constVal = tryConstLow(src)) != -1) {
@@ -498,27 +473,12 @@ void Expression::makeBinaryOp(RPNCommand op, Expression &&src1, Expression const
 
 			data = op_exponent(lval, rval);
 			break;
-
-		case RPN_NEG:
-		case RPN_NOT:
-		case RPN_LOGNOT:
-		case RPN_BANK_SYM:
-		case RPN_BANK_SECT:
-		case RPN_BANK_SELF:
-		case RPN_SIZEOF_SECT:
-		case RPN_STARTOF_SECT:
-		case RPN_SIZEOF_SECTTYPE:
-		case RPN_STARTOF_SECTTYPE:
-		case RPN_HRAM:
-		case RPN_RST:
-		case RPN_HIGH:
-		case RPN_LOW:
-		case RPN_BITWIDTH:
-		case RPN_TZCOUNT:
-		case RPN_CONST:
-		case RPN_SYM:
-			fatalerror("%d is not a binary operator\n", op);
+		default:
+			// `makeBinaryOp` should never be called with a non-binary operator!
+			// LCOV_EXCL_START
+			unreachable_();
 		}
+		// LCOV_EXCL_STOP
 	} else if (op == RPN_SUB && src1.isDiffConstant(src2.symbolOf())) {
 		data = src1.symbolOf()->getValue() - src2.symbolOf()->getValue();
 	} else if ((op == RPN_LOGAND || op == RPN_AND) && tryConstZero(src1, src2)) {
@@ -605,10 +565,24 @@ void Expression::makeCheckRST() {
 	}
 }
 
+void Expression::makeCheckBitIndex(uint8_t mask) {
+	assume((mask & 0xC0) != 0x00); // The high two bits must correspond to BIT, RES, or SET
+
+	if (!isKnown()) {
+		uint8_t *ptr = reserveSpace(2);
+		*ptr++ = RPN_BIT_INDEX;
+		*ptr = mask;
+	} else if (int32_t val = value(); val & ~0x07) {
+		// A valid bit index must be masked with 0x07
+		static char const *instructions[4] = {"instruction", "BIT", "RES", "SET"};
+		error("Invalid bit index %" PRId32 " for %s\n", val, instructions[mask >> 6]);
+	}
+}
+
 // Checks that an RPN expression's value fits within N bits (signed or unsigned)
 void Expression::checkNBit(uint8_t n) const {
 	if (isKnown()) {
-		::checkNBit(value(), n, "Expression");
+		::checkNBit(value(), n, nullptr);
 	}
 }
 
@@ -617,11 +591,23 @@ bool checkNBit(int32_t v, uint8_t n, char const *name) {
 	assume(n < CHAR_BIT * sizeof(int)); // Otherwise `1 << n` is UB
 
 	if (v < -(1 << n) || v >= 1 << n) {
-		warning(WARNING_TRUNCATION_1, "%s must be %u-bit\n", name, n);
+		warning(
+		    WARNING_TRUNCATION_1,
+		    n == 8 && !name ? "%s must be %u-bit; use LOW() to force 8-bit\n"
+		                    : "%s must be %u-bit\n",
+		    name ? name : "Expression",
+		    n
+		);
 		return false;
 	}
 	if (v < -(1 << (n - 1))) {
-		warning(WARNING_TRUNCATION_2, "%s must be %u-bit\n", name, n);
+		warning(
+		    WARNING_TRUNCATION_2,
+		    n == 8 && !name ? "%s must be %u-bit; use LOW() to force 8-bit\n"
+		                    : "%s must be %u-bit\n",
+		    name ? name : "Expression",
+		    n
+		);
 		return false;
 	}
 
