@@ -15,6 +15,7 @@
 #include "helpers.hpp"
 #include "linkdefs.hpp"
 #include "platform.hpp"
+#include "util.hpp"
 
 #include "link/main.hpp"
 #include "link/section.hpp"
@@ -30,6 +31,7 @@ FILE *mapFile;
 struct SortedSymbol {
 	Symbol const *sym;
 	uint16_t addr;
+	uint16_t parentAddr;
 };
 
 struct SortedSections {
@@ -259,29 +261,13 @@ static void writeROM() {
 	}
 }
 
-// Checks whether a symbol is legal for a sym file or map file.
-// Eliminates anonymous labels, which start with a '!'.
-static bool isLegalSymbol(Symbol const &sym) {
-	if (sym.name.empty()) {
-		return false;
-	}
-	char c = sym.name[0];
-	return (c >= 'A' && c <= 'Z') || (c >= 'a' && c <= 'z') || c == '_';
-}
-
-// Checks whether this character is legal in a symbol's name in a sym file
-static bool isLegalForSymName(char c) {
-	return (c >= 'A' && c <= 'Z') || (c >= 'a' && c <= 'z') || (c >= '0' && c <= '9') || c == '_'
-	       || c == '@' || c == '#' || c == '$' || c == '.';
-}
-
 // Prints a symbol's name to a file, assuming that the first character is legal.
 // Illegal characters are UTF-8-decoded (errors are replaced by U+FFFD) and emitted as '\u'/'\U'.
 static void printSymName(std::string const &name, FILE *file) {
 	for (char const *ptr = name.c_str(); *ptr != '\0';) {
 		char c = *ptr;
 
-		if (isLegalForSymName(c)) {
+		if (continuesIdentifier(c)) {
 			// Output legal ASCII characters as-is
 			putc(c, file);
 			++ptr;
@@ -311,33 +297,28 @@ static void printSymName(std::string const &name, FILE *file) {
 }
 
 // Comparator function for `std::stable_sort` to sort symbols
-// Symbols are ordered by address, then by parentage
 static bool compareSymbols(SortedSymbol const &sym1, SortedSymbol const &sym2) {
+	// First, sort by address
 	if (sym1.addr != sym2.addr) {
 		return sym1.addr < sym2.addr;
 	}
 
+	// Second, sort by locality (global before local)
 	std::string const &sym1_name = sym1.sym->name;
 	std::string const &sym2_name = sym2.sym->name;
-	bool sym1_local = sym1_name.find(".") != std::string::npos;
-	bool sym2_local = sym2_name.find(".") != std::string::npos;
-
+	bool sym1_local = sym1_name.find('.') != std::string::npos;
+	bool sym2_local = sym2_name.find('.') != std::string::npos;
 	if (sym1_local != sym2_local) {
-		size_t sym1_len = sym1_name.length();
-		size_t sym2_len = sym2_name.length();
-
-		// Sort parent labels before their child local labels
-		if (sym2_name.starts_with(sym1_name) && sym2_name[sym1_len] == '.') {
-			return true;
-		}
-		if (sym1_name.starts_with(sym2_name) && sym1_name[sym2_len] == '.') {
-			return false;
-		}
-		// Sort local labels before unrelated global labels
-		return sym1_local;
+		return sym1_local < sym2_local;
 	}
 
-	return false;
+	// Third, sort by parent address
+	if (sym1.parentAddr != sym2.parentAddr) {
+		return sym1.parentAddr < sym2.parentAddr;
+	}
+
+	// Fourth, sort by name
+	return sym1_name < sym2_name;
 }
 
 // Write a bank's contents to the sym file
@@ -373,11 +354,20 @@ static void writeSymBank(SortedSections const &bankSections, SectionType type, u
 	forEachSortedSection(sect, {
 		for (Symbol const *sym : sect->symbols) {
 			// Don't output symbols that begin with an illegal character
-			if (isLegalSymbol(*sym)) {
-				symList.push_back({
-				    .sym = sym,
-				    .addr = static_cast<uint16_t>(sym->label().offset + sect->org),
-				});
+			if (!sym->name.empty() && startsIdentifier(sym->name[0])) {
+				uint16_t addr = static_cast<uint16_t>(sym->label().offset + sect->org);
+				uint16_t parentAddr = addr;
+				if (auto pos = sym->name.find('.'); pos != std::string::npos) {
+					std::string parentName = sym->name.substr(0, pos);
+					if (Symbol const *parentSym = sym_GetSymbol(parentName);
+					    parentSym && parentSym->data.holds<Label>()) {
+						auto const &parentLabel = parentSym->label();
+						assume(parentLabel.section != nullptr);
+						parentAddr =
+						    static_cast<uint16_t>(parentLabel.offset + parentLabel.section->org);
+					}
+				}
+				symList.push_back({.sym = sym, .addr = addr, .parentAddr = parentAddr});
 			}
 		}
 	});
@@ -477,7 +467,7 @@ static void writeMapBank(SortedSections const &sectList, SectionType type, uint3
 			for (uint16_t org = sect->org; sect; sect = sect->nextu.get()) {
 				for (Symbol *sym : sect->symbols) {
 					// Don't output symbols that begin with an illegal character
-					if (isLegalSymbol(*sym)) {
+					if (!sym->name.empty() && startsIdentifier(sym->name[0])) {
 						// Space matches "\tSECTION: $xxxx ..."
 						fprintf(mapFile, "\t         $%04" PRIx32 " = ", sym->label().offset + org);
 						printSymName(sym->name, mapFile);
