@@ -9,7 +9,7 @@
 #include <string.h>
 #include <tuple>
 
-#include "helpers.hpp" // assume
+#include "helpers.hpp" // assume, literal_strlen
 #include "linkdefs.hpp"
 #include "platform.hpp"
 
@@ -34,28 +34,31 @@ static char const *delim = " \f\n\r\t\v"; // Whitespace according to the C and P
 
 static int
     nextLine(std::vector<char> &lineBuf, uint32_t &lineNo, FileStackNode const &where, FILE *file) {
-retry:
-	++lineNo;
-	int firstChar = getc(file);
-	lineBuf.clear();
+	int firstChar;
+	for (;;) {
+		++lineNo;
+		firstChar = getc(file);
+		lineBuf.clear();
 
-	switch (firstChar) {
-	case EOF:
-		return EOF;
-	case ';':
-		// Discard comment line
-		// TODO: if `;!FILE [...]` on the first line (`lineNo`), return it
-		do {
-			firstChar = getc(file);
-		} while (firstChar != EOF && firstChar != '\r' && firstChar != '\n');
-		[[fallthrough]];
-	case '\r':
-		if (firstChar == '\r' && getc(file) != '\n') {
-			consumeLF(where, lineNo, file);
+		switch (firstChar) {
+		case EOF:
+			return EOF;
+		case ';':
+			// Discard comment line
+			// TODO: if `;!FILE [...]` on the first line (`lineNo`), return it
+			do {
+				firstChar = getc(file);
+			} while (firstChar != EOF && firstChar != '\r' && firstChar != '\n');
+			[[fallthrough]];
+		case '\r':
+			if (firstChar == '\r' && getc(file) != '\n') {
+				consumeLF(where, lineNo, file);
+			}
+			[[fallthrough]];
+		case '\n':
+			continue;
 		}
-		[[fallthrough]];
-	case '\n':
-		goto retry;
+		break;
 	}
 
 	for (;;) {
@@ -446,7 +449,7 @@ void sdobj_ReadFile(FileStackNode const &where, FILE *file, std::vector<Symbol>
 				// It's fine to keep modifying the symbol after `AddSymbol`, only
 				// the name must not be modified
 			}
-			if (strncasecmp(&token[1], "ef", 2) != 0) {
+			if (strncasecmp(&token[1], "ef", literal_strlen("ef")) != 0) {
 				fatal(&where, lineNo, "'S' line is neither \"Def\" nor \"Ref\"");
 			}
 
